@@ -1,9 +1,9 @@
 #ifndef STAN_MATH_FWD_SCAL_FUN_LOG1M_HPP
 #define STAN_MATH_FWD_SCAL_FUN_LOG1M_HPP
 
+#include <stan/math/fwd/meta.hpp>
 #include <stan/math/fwd/core.hpp>
 #include <stan/math/prim/scal/fun/log1m.hpp>
-#include <stan/math/prim/scal/fun/constants.hpp>
 
 namespace stan {
 namespace math {
