@@ -1,14 +1,10 @@
 #ifndef STAN_MATH_REV_SCAL_FUN_LOG_MIX_HPP
 #define STAN_MATH_REV_SCAL_FUN_LOG_MIX_HPP
 
-#include <stan/math/prim/scal/err/check_bounded.hpp>
-#include <stan/math/prim/scal/err/check_not_nan.hpp>
-#include <stan/math/prim/scal/fun/log1m.hpp>
+#include <stan/math/rev/meta.hpp>
 #include <stan/math/prim/scal/fun/value_of.hpp>
 #include <stan/math/prim/scal/fun/log_mix.hpp>
 #include <stan/math/rev/scal/fun/value_of.hpp>
-#include <stan/math/prim/scal/meta/is_constant_struct.hpp>
-#include <stan/math/prim/scal/meta/operands_and_partials.hpp>
 #include <cmath>
 
 namespace stan {
@@ -78,7 +74,7 @@ inline void log_mix_partial_helper(
  * @return log mixture of densities in specified proportion
  */
 template <typename T_theta, typename T_lambda1, typename T_lambda2>
-inline typename return_type<T_theta, T_lambda1, T_lambda2>::type log_mix(
+inline return_type_t<T_theta, T_lambda1, T_lambda2> log_mix(
     const T_theta& theta, const T_lambda1& lambda1, const T_lambda2& lambda2) {
   using std::log;
 
@@ -109,16 +105,19 @@ inline typename return_type<T_theta, T_lambda1, T_lambda2>::type log_mix(
     one_m_t_prod_exp_lam2_m_lam1 = 1.0 - value_of(theta);
   }
 
-  if (!is_constant_struct<T_theta>::value)
+  if (!is_constant_all<T_theta>::value) {
     ops_partials.edge1_.partials_[0]
         = one_m_exp_lam2_m_lam1 * one_d_t_plus_one_m_t_prod_exp_lam2_m_lam1;
-  if (!is_constant_struct<T_lambda1>::value)
+  }
+  if (!is_constant_all<T_lambda1>::value) {
     ops_partials.edge2_.partials_[0]
         = theta_double * one_d_t_plus_one_m_t_prod_exp_lam2_m_lam1;
-  if (!is_constant_struct<T_lambda2>::value)
+  }
+  if (!is_constant_all<T_lambda2>::value) {
     ops_partials.edge3_.partials_[0]
         = one_m_t_prod_exp_lam2_m_lam1
           * one_d_t_plus_one_m_t_prod_exp_lam2_m_lam1;
+  }
 
   return ops_partials.build(log_mix_function_value);
 }
