@@ -1,6 +1,7 @@
 #ifndef STAN_MATH_REV_SCAL_FUN_TRUNC_HPP
 #define STAN_MATH_REV_SCAL_FUN_TRUNC_HPP
 
+#include <stan/math/rev/meta.hpp>
 #include <stan/math/rev/core.hpp>
 #include <stan/math/prim/scal/fun/is_nan.hpp>
 #include <stan/math/prim/scal/fun/trunc.hpp>
@@ -14,8 +15,9 @@ class trunc_vari : public op_v_vari {
  public:
   explicit trunc_vari(vari* avi) : op_v_vari(trunc(avi->val_), avi) {}
   void chain() {
-    if (unlikely(is_nan(avi_->val_)))
+    if (unlikely(is_nan(avi_->val_))) {
       avi_->adj_ = std::numeric_limits<double>::quiet_NaN();
+    }
   }
 };
 }  // namespace internal
